SetAttr

Trait SetAttr 

pub trait SetAttr {
    // Required method
    fn set_attr(
        &self,
        pattern: &str,
        attributes: &[&str],
        gitattributes: &Path,
    ) -> Result<(), Error>;
}
A trait which provides methods for settings attributes in a Git repository.

Required Methods

fn set_attr( &self, pattern: &str, attributes: &[&str], gitattributes: &Path, ) -> Result<(), Error>

Set attributes in the given .gitattributes file.

The file will be created if it does not already exist.

Implementors